Module: Clowk::Phlex::UI::Icons

Defined in:
lib/clowk/phlex/ui/icons.rb

Overview

Icons — the small set of Heroicons (outline, MIT) the components use, vendored so the gem carries no icon dependency. Rendered by the Component#icon helper. Add a path here to use a new glyph.

Source: https://heroicons.com (24×24 outline, stroke currentColor).

Constant Summary collapse

PATHS =
{
  ellipsis_vertical: "M12 6.75a.75.75 0 1 1 0-1.5.75.75 0 0 1 0 1.5ZM12 12.75a.75.75 0 1 1 0-1.5.75.75 0 0 1 0 1.5ZM12 18.75a.75.75 0 1 1 0-1.5.75.75 0 0 1 0 1.5Z",
  arrows_pointing_out: "M3.75 3.75v4.5m0-4.5h4.5m-4.5 0L9 9M3.75 20.25v-4.5m0 4.5h4.5m-4.5 0L9 15M20.25 3.75h-4.5m4.5 0v4.5m0-4.5L15 9m5.25 11.25h-4.5m4.5 0v-4.5m0 4.5L15 15",
  check: "m4.5 12.75 6 6 9-13.5",
  chevron_down: "m19.5 8.25-7.5 7.5-7.5-7.5",
  calendar_days: "M6.75 3v2.25M17.25 3v2.25M3 18.75V7.5a2.25 2.25 0 0 1 2.25-2.25h13.5A2.25 2.25 0 0 1 21 7.5v11.25m-18 0A2.25 2.25 0 0 0 5.25 21h13.5A2.25 2.25 0 0 0 21 18.75m-18 0v-7.5A2.25 2.25 0 0 1 5.25 9h13.5A2.25 2.25 0 0 1 21 11.25v7.5m-9-6h.008v.008H12v-.008ZM12 15h.008v.008H12V15Zm0 2.25h.008v.008H12v-.008ZM9.75 15h.008v.008H9.75V15Zm0 2.25h.008v.008H9.75v-.008ZM7.5 15h.008v.008H7.5V15Zm0 2.25h.008v.008H7.5v-.008Zm6.75-4.5h.008v.008h-.008v-.008Zm0 2.25h.008v.008h-.008V15Zm0 2.25h.008v.008h-.008v-.008Zm2.25-4.5h.008v.008H16.5v-.008Zm0 2.25h.008v.008H16.5V15Z",
  bars_3: "M3.75 6.75h16.5M3.75 12h16.5m-16.5 5.25h16.5",
  x_mark: "M6 18 18 6M6 6l12 12"
}.freeze